"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[212],{8030:function(e,t,n){n.d(t,{Z:function(){return s}});var r=n(2265);/**
 * @license lucide-react v0.396.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let o=e=>e.replace(/([a-z0-9])([A-Z])/g,"$1-$2").toLowerCase(),l=function(){for(var e=arguments.length,t=Array(e),n=0;n<e;n++)t[n]=arguments[n];return t.filter((e,t,n)=>!!e&&n.indexOf(e)===t).join(" ")};/**
 * @license lucide-react v0.396.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */var u={xmlns:"http://www.w3.org/2000/svg",width:24,height:24,viewBox:"0 0 24 24",fill:"none",stroke:"currentColor",strokeWidth:2,strokeLinecap:"round",strokeLinejoin:"round"};/**
 * @license lucide-react v0.396.0 - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */let i=(0,r.forwardRef)((e,t)=>{let{color:n="currentColor",size:o=24,strokeWidth:i=2,absoluteStrokeWidth:s,className:c="",children:a,iconNode:d,...f}=e;return(0,r.createElement)("svg",{ref:t,...u,width:o,height:o,stroke:n,strokeWidth:s?24*Number(i)/Number(o):i,className:l("lucide",c),...f},[...d.map(e=>{let[t,n]=e;return(0,r.createElement)(t,n)}),...Array.isArray(a)?a:[a]])}),s=(e,t)=>{let n=(0,r.forwardRef)((n,u)=>{let{className:s,...c}=n;return(0,r.createElement)(i,{ref:u,iconNode:t,className:l("lucide-".concat(o(e)),s),...c})});return n.displayName="".concat(e),n}},8149:function(e,t,n){n.d(t,{M:function(){return r}});function r(e,t,{checkForDefaultPrevented:n=!0}={}){return function(r){if(null==e||e(r),!1===n||!r.defaultPrevented)return null==t?void 0:t(r)}}},976:function(e,t,n){n.d(t,{B:function(){return i}});var r=n(2265),o=n(8324),l=n(1584),u=n(1538);function i(e){let t=e+"CollectionProvider",[n,i]=(0,o.b)(t),[s,c]=n(t,{collectionRef:{current:null},itemMap:new Map}),a=e+"CollectionSlot",d=r.forwardRef((e,t)=>{let{scope:n,children:o}=e,i=c(a,n),s=(0,l.e)(t,i.collectionRef);return r.createElement(u.g7,{ref:s},o)}),f=e+"CollectionItemSlot",v="data-radix-collection-item";return[{Provider:e=>{let{scope:t,children:n}=e,o=r.useRef(null),l=r.useRef(new Map).current;return r.createElement(s,{scope:t,itemMap:l,collectionRef:o},n)},Slot:d,ItemSlot:r.forwardRef((e,t)=>{let{scope:n,children:o,...i}=e,s=r.useRef(null),a=(0,l.e)(t,s),d=c(f,n);return r.useEffect(()=>(d.itemMap.set(s,{ref:s,...i}),()=>void d.itemMap.delete(s))),r.createElement(u.g7,{[v]:"",ref:a},o)})},function(t){let n=c(e+"CollectionConsumer",t);return r.useCallback(()=>{let e=n.collectionRef.current;if(!e)return[];let t=Array.from(e.querySelectorAll(`[${v}]`));return Array.from(n.itemMap.values()).sort((e,n)=>t.indexOf(e.ref.current)-t.indexOf(n.ref.current))},[n.collectionRef,n.itemMap])},i]}},8324:function(e,t,n){n.d(t,{b:function(){return o}});var r=n(2265);function o(e,t=[]){let n=[],o=()=>{let t=n.map(e=>(0,r.createContext)(e));return function(n){let o=(null==n?void 0:n[e])||t;return(0,r.useMemo)(()=>({[`__scope${e}`]:{...n,[e]:o}}),[n,o])}};return o.scopeName=e,[function(t,o){let l=(0,r.createContext)(o),u=n.length;function i(t){let{scope:n,children:o,...i}=t,s=(null==n?void 0:n[e][u])||l,c=(0,r.useMemo)(()=>i,Object.values(i));return(0,r.createElement)(s.Provider,{value:c},o)}return n=[...n,o],i.displayName=t+"Provider",[i,function(n,i){let s=(null==i?void 0:i[e][u])||l,c=(0,r.useContext)(s);if(c)return c;if(void 0!==o)return o;throw Error(`\`${n}\` must be used within \`${t}\``)}]},function(...e){let t=e[0];if(1===e.length)return t;let n=()=>{let n=e.map(e=>({useScope:e(),scopeName:e.scopeName}));return function(e){let o=n.reduce((t,{useScope:n,scopeName:r})=>{let o=n(e)[`__scope${r}`];return{...t,...o}},{});return(0,r.useMemo)(()=>({[`__scope${t.scopeName}`]:o}),[o])}};return n.scopeName=t.scopeName,n}(o,...t)]}},3938:function(e,t,n){let r;n.d(t,{I0:function(){return E},XB:function(){return f},fC:function(){return h}});var o=n(2988),l=n(2265),u=n(8149),i=n(5171),s=n(1584),c=n(5137);let a="dismissableLayer.update",d=(0,l.createContext)({layers:new Set,layersWithOutsidePointerEventsDisabled:new Set,branches:new Set}),f=(0,l.forwardRef)((e,t)=>{var n;let{disableOutsidePointerEvents:f=!1,onEscapeKeyDown:v,onPointerDownOutside:h,onFocusOutside:E,onInteractOutside:b,onDismiss:w,...y}=e,g=(0,l.useContext)(d),[C,P]=(0,l.useState)(null),R=null!==(n=null==C?void 0:C.ownerDocument)&&void 0!==n?n:null==globalThis?void 0:globalThis.document,[,k]=(0,l.useState)({}),L=(0,s.e)(t,e=>P(e)),W=Array.from(g.layers),[O]=[...g.layersWithOutsidePointerEventsDisabled].slice(-1),D=W.indexOf(O),T=C?W.indexOf(C):-1,M=g.layersWithOutsidePointerEventsDisabled.size>0,N=T>=D,x=function(e,t=null==globalThis?void 0:globalThis.document){let n=(0,c.W)(e),r=(0,l.useRef)(!1),o=(0,l.useRef)(()=>{});return(0,l.useEffect)(()=>{let e=e=>{if(e.target&&!r.current){let r={originalEvent:e};function l(){m("dismissableLayer.pointerDownOutside",n,r,{discrete:!0})}"touch"===e.pointerType?(t.removeEventListener("click",o.current),o.current=l,t.addEventListener("click",o.current,{once:!0})):l()}else t.removeEventListener("click",o.current);r.current=!1},l=window.setTimeout(()=>{t.addEventListener("pointerdown",e)},0);return()=>{window.clearTimeout(l),t.removeEventListener("pointerdown",e),t.removeEventListener("click",o.current)}},[t,n]),{onPointerDownCapture:()=>r.current=!0}}(e=>{let t=e.target,n=[...g.branches].some(e=>e.contains(t));!N||n||(null==h||h(e),null==b||b(e),e.defaultPrevented||null==w||w())},R),S=function(e,t=null==globalThis?void 0:globalThis.document){let n=(0,c.W)(e),r=(0,l.useRef)(!1);return(0,l.useEffect)(()=>{let e=e=>{e.target&&!r.current&&m("dismissableLayer.focusOutside",n,{originalEvent:e},{discrete:!1})};return t.addEventListener("focusin",e),()=>t.removeEventListener("focusin",e)},[t,n]),{onFocusCapture:()=>r.current=!0,onBlurCapture:()=>r.current=!1}}(e=>{let t=e.target;[...g.branches].some(e=>e.contains(t))||(null==E||E(e),null==b||b(e),e.defaultPrevented||null==w||w())},R);return!function(e,t=null==globalThis?void 0:globalThis.document){let n=(0,c.W)(e);(0,l.useEffect)(()=>{let e=e=>{"Escape"===e.key&&n(e)};return t.addEventListener("keydown",e),()=>t.removeEventListener("keydown",e)},[n,t])}(e=>{T!==g.layers.size-1||(null==v||v(e),!e.defaultPrevented&&w&&(e.preventDefault(),w()))},R),(0,l.useEffect)(()=>{if(C)return f&&(0===g.layersWithOutsidePointerEventsDisabled.size&&(r=R.body.style.pointerEvents,R.body.style.pointerEvents="none"),g.layersWithOutsidePointerEventsDisabled.add(C)),g.layers.add(C),p(),()=>{f&&1===g.layersWithOutsidePointerEventsDisabled.size&&(R.body.style.pointerEvents=r)}},[C,R,f,g]),(0,l.useEffect)(()=>()=>{C&&(g.layers.delete(C),g.layersWithOutsidePointerEventsDisabled.delete(C),p())},[C,g]),(0,l.useEffect)(()=>{let e=()=>k({});return document.addEventListener(a,e),()=>document.removeEventListener(a,e)},[]),(0,l.createElement)(i.WV.div,(0,o.Z)({},y,{ref:L,style:{pointerEvents:M?N?"auto":"none":void 0,...e.style},onFocusCapture:(0,u.M)(e.onFocusCapture,S.onFocusCapture),onBlurCapture:(0,u.M)(e.onBlurCapture,S.onBlurCapture),onPointerDownCapture:(0,u.M)(e.onPointerDownCapture,x.onPointerDownCapture)}))}),v=(0,l.forwardRef)((e,t)=>{let n=(0,l.useContext)(d),r=(0,l.useRef)(null),u=(0,s.e)(t,r);return(0,l.useEffect)(()=>{let e=r.current;if(e)return n.branches.add(e),()=>{n.branches.delete(e)}},[n.branches]),(0,l.createElement)(i.WV.div,(0,o.Z)({},e,{ref:u}))});function p(){let e=new CustomEvent(a);document.dispatchEvent(e)}function m(e,t,n,{discrete:r}){let o=n.originalEvent.target,l=new CustomEvent(e,{bubbles:!1,cancelable:!0,detail:n});t&&o.addEventListener(e,t,{once:!0}),r?(0,i.jH)(o,l):o.dispatchEvent(l)}let h=f,E=v},6935:function(e,t,n){n.d(t,{h:function(){return i}});var r=n(2988),o=n(2265),l=n(4887),u=n(5171);let i=(0,o.forwardRef)((e,t)=>{var n;let{container:i=null==globalThis?void 0:null===(n=globalThis.document)||void 0===n?void 0:n.body,...s}=e;return i?l.createPortal((0,o.createElement)(u.WV.div,(0,r.Z)({},s,{ref:t})),i):null})},5137:function(e,t,n){n.d(t,{W:function(){return o}});var r=n(2265);function o(e){let t=(0,r.useRef)(e);return(0,r.useEffect)(()=>{t.current=e}),(0,r.useMemo)(()=>(...e)=>{var n;return null===(n=t.current)||void 0===n?void 0:n.call(t,...e)},[])}},1715:function(e,t,n){n.d(t,{T:function(){return l}});var r=n(2265),o=n(5137);function l({prop:e,defaultProp:t,onChange:n=()=>{}}){let[l,u]=function({defaultProp:e,onChange:t}){let n=(0,r.useState)(e),[l]=n,u=(0,r.useRef)(l),i=(0,o.W)(t);return(0,r.useEffect)(()=>{u.current!==l&&(i(l),u.current=l)},[l,u,i]),n}({defaultProp:t,onChange:n}),i=void 0!==e,s=i?e:l,c=(0,o.W)(n);return[s,(0,r.useCallback)(t=>{if(i){let n="function"==typeof t?t(e):t;n!==e&&c(n)}else u(t)},[i,e,u,c])]}},1336:function(e,t,n){n.d(t,{b:function(){return o}});var r=n(2265);let o=(null==globalThis?void 0:globalThis.document)?r.useLayoutEffect:()=>{}},1725:function(e,t,n){n.d(t,{T:function(){return u}});var r=n(2988),o=n(2265),l=n(5171);let u=(0,o.forwardRef)((e,t)=>(0,o.createElement)(l.WV.span,(0,r.Z)({},e,{ref:t,style:{position:"absolute",border:0,width:1,height:1,padding:0,margin:-1,overflow:"hidden",clip:"rect(0, 0, 0, 0)",whiteSpace:"nowrap",wordWrap:"normal",...e.style}})))}}]);